# Model Support

Get the newest info here: [https://github.com/vllm-project/vllm-ascend/issues/1608](https://github.com/vllm-project/vllm-ascend/issues/1608)

## Text-only Language Models

### Generative Models
| Model | Supported | Note |
|-------|-----------|------|
| DeepSeek v3 | ✅ | |
| DeepSeek R1 | ✅ | |
| DeepSeek Distill (Qwen/LLama) | ✅ | |
| Qwen3 | ✅ | |
| Qwen3-Moe | ✅ | |
| Qwen2.5 | ✅ | |
| QwQ-32B | ✅ | |
| LLama3.1/3.2 | ✅ | |
| Internlm | ✅ | |
| Baichuan | ✅ | |
| Phi-4-mini | ✅ | |
| MiniCPM | ✅ | |
| MiniCPM3 | ✅ | |
| LLama4 | ✅ | |
| Mistral | | Need test |
| DeepSeek v2.5 | |Need test |
| Gemma-2 | | Need test |
| Mllama |  |Need test|
| Gemma-3 | ❌ | [#496](https://github.com/vllm-project/vllm-ascend/issues/496) |
| ChatGLM | ❌ | [#554](https://github.com/vllm-project/vllm-ascend/issues/554) |

### Pooling Models
| Model | Supported | Note |
|-------|---------|------|
| XLM-RoBERTa-based | ✅ |  |
| Molmo | ✅ |  |

## Multimodal Language Models

### Generative Models
| Model | Supported | Note |
|-------|-----------|------|
| Qwen2-VL | ✅ | |
| Qwen2.5-VL | ✅ | |
| LLaVA 1.5 | ✅ | |
| LLaVA 1.6 | ✅ | [#553](https://github.com/vllm-project/vllm-ascend/issues/553) |
| InternVL2 | ✅ | |
| InternVL2.5 | ✅ | |
| Qwen2-Audio | ✅ |  |
| LLaVA-Next |  | Need test |
| LLaVA-Next-Video | | Need test |
| Phi-3-Vison/Phi-3.5-Vison | | Need test |
| GLM-4v | | Need test |
| Ultravox |  | Need test |
